summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/tests/kogenstylestest.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/tests/kogenstylestest.cpp')
-rw-r--r--lib/kofficecore/tests/kogenstylestest.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/lib/kofficecore/tests/kogenstylestest.cpp b/lib/kofficecore/tests/kogenstylestest.cpp
index ef9150f6..165d0ce9 100644
--- a/lib/kofficecore/tests/kogenstylestest.cpp
+++ b/lib/kofficecore/tests/kogenstylestest.cpp
@@ -66,8 +66,8 @@ int testLookup()
KoGenStyle third( KoGenStyle::STYLE_AUTO, "paragraph", secondName ); // inherited style
third.addProperty( "style:margin-left", "1.249cm" );
- third.addProperty( "style:page-number", "0" ); // same as tqparent
- third.addProperty( "style:foobar", "3", KoGenStyle::TextType ); // different from tqparent
+ third.addProperty( "style:page-number", "0" ); // same as parent
+ third.addProperty( "style:foobar", "3", KoGenStyle::TextType ); // different from parent
assert( third.parentName() == secondName );
TQString thirdName = coll.lookup( third, "P" );
@@ -88,7 +88,7 @@ int testLookup()
sameAsParent.addStyleMap( map1 );
sameAsParent.addStyleMap( map2 );
TQString sapName = coll.lookup( sameAsParent, "foobar" );
- kdDebug() << "The 'same as tqparent' style got assigned the name " << sapName << endl;
+ kdDebug() << "The 'same as parent' style got assigned the name " << sapName << endl;
assert( sapName == secondName );
assert( coll.styles().count() == 3 );
@@ -119,7 +119,7 @@ int testLookup()
TEST_BEGIN( 0, 0 );
third.writeStyle( &writer, coll, "style:style", thirdName, "style:paragraph-properties" );
- TEST_END( "XML for third style", "<r>\n <style:style style:name=\"P1\" style:tqparent-style-name=\"A1\" style:family=\"paragraph\">\n <style:paragraph-properties style:margin-left=\"1.249cm\"/>\n <style:text-properties style:foobar=\"3\"/>\n </style:style>\n</r>\n" );
+ TEST_END( "XML for third style", "<r>\n <style:style style:name=\"P1\" style:parent-style-name=\"A1\" style:family=\"paragraph\">\n <style:paragraph-properties style:margin-left=\"1.249cm\"/>\n <style:text-properties style:foobar=\"3\"/>\n </style:style>\n</r>\n" );
coll.markStyleForStylesXml( firstName );
{
@@ -166,11 +166,11 @@ int testDefaultStyle()
// The kspread case: not writing out all properties, only if they differ
// from the default style.
// KoGenStyles doesn't fetch info from the tqparent style when testing
// for equality, so KSpread uses isEmpty() to check for equality-to-tqparent.
KoGenStyle dataStyle( KoGenStyle::STYLE_AUTO, "paragraph", defaultStyleName );
assert( dataStyle.isEmpty() );
// and then it doesn't look up the auto style, but rather uses the tqparent style directly.
return 0;
}
@@ -201,13 +201,13 @@ int testUserStyles()
// And now, what if the data uses that style?
// This is like sameAsParent in the other test, but this time the
- // tqparent is a STYLE_USER...
+ // parent is a STYLE_USER...
KoGenStyle dataStyle( KoGenStyle::STYLE_AUTO, "paragraph", user2StyleName );
dataStyle.addProperty( "myfont", "isBold" );
TQString dataStyleName = coll.lookup( dataStyle, "DataStyle" );
kdDebug() << "The auto style got assigned the name " << dataStyleName << endl;
- assert( dataStyleName == "User2" ); // it found the tqparent as equal
+ assert( dataStyleName == "User2" ); // it found the parent as equal
// Let's do the opposite test, just to make sure
KoGenStyle dataStyle2( KoGenStyle::STYLE_AUTO, "paragraph", user2StyleName );
@@ -166,11 +166,11 @@ int testDefaultStyle()
// The kspread case: not writing out all properties, only if they differ
// from the default style.
- // KoGenStyles doesn't fetch info from the tqparent style when testing
- // for equality, so KSpread uses isEmpty() to check for equality-to-tqparent.
+ // KoGenStyles doesn't fetch info from the parent style when testing
+ // for equality, so KSpread uses isEmpty() to check for equality-to-parent.
KoGenStyle dataStyle( KoGenStyle::STYLE_AUTO, "paragraph", defaultStyleName );
assert( dataStyle.isEmpty() );
@@ -166,11 +166,11 @@ int testDefaultStyle()
KoGenStyle dataStyle( KoGenStyle::STYLE_AUTO, "paragraph", defaultStyleName );
assert( dataStyle.isEmpty() );
- // and then it doesn't look up the auto style, but rather uses the tqparent style directly.
+ // and then it doesn't look up the auto style, but rather uses the parent style directly.
return 0;
}